==> alembic-1.7.4.tar.gz: alembic-1.7.4/maya/AbcImport/AlembicImportFileTranslator.h <==
//-*****************************************************************************
//
// Copyright (c) 2009-2012,
//  Sony Pictures Imageworks, Inc. and
//  Industrial Light & Magic, a division of Lucasfilm Entertainment Company Ltd.
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// *       Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// *       Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
// *       Neither the name of Sony Pictures Imageworks, nor
// Industrial Light & Magic nor the names of their contributors may be used
// to endorse or promote products derived from this software without specific
// prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//-*****************************************************************************

#ifndef ABCIMPORT_ALEMBIC_IMPORT_FILE_TRANSLATOR_H_
#define ABCIMPORT_ALEMBIC_IMPORT_FILE_TRANSLATOR_H_

#include <maya/MPxFileTranslator.h>

class AlembicImportFileTranslator : public MPxFileTranslator
{
public:

    AlembicImportFileTranslator() : MPxFileTranslator() {}

    virtual ~AlembicImportFileTranslator() {}

    MStatus reader (const MFileObject& file,
                    const MString& optionsString,
                    MPxFileTranslator::FileAccessMode mode);

    MFileKind identifyFile(const MFileObject& filename,
                           const char* buffer,
                           short size) const;

    bool haveReadMethod() const
    {
        return true;
    }

    bool haveNamespaceSupport() const
    {
        return true;
    }

    MString defaultExtension() const
    {
        return "abc";
    }

    MString filter() const
    {
        return "*.abc";
    }

    static void* creator()
    {
        return new AlembicImportFileTranslator;
    }
};

#endif  // ABCIMPORT_ALEMBIC_IMPORT_FILE_TRANSLATOR_H_

==> alembic_1.7.12.orig.tar.gz: alembic-1.7.12/maya/AbcImport/AlembicImportFileTranslator.h <==
//-*****************************************************************************
//
// Copyright (c) 2009-2012,
//  Sony Pictures Imageworks, Inc. and
//  Industrial Light & Magic, a division of Lucasfilm Entertainment Company Ltd.
//
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
// *       Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// *       Redistributions in binary form must reproduce the above
// copyright notice, this list of conditions and the following disclaimer
// in the documentation and/or other materials provided with the
// distribution.
// *       Neither the name of Sony Pictures Imageworks, nor
// Industrial Light & Magic nor the names of their contributors may be used
// to endorse or promote products derived from this software without specific
// prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
//-*****************************************************************************

#ifndef ABCIMPORT_ALEMBIC_IMPORT_FILE_TRANSLATOR_H_
#define ABCIMPORT_ALEMBIC_IMPORT_FILE_TRANSLATOR_H_

#include <maya/MPxFileTranslator.h>

class AlembicImportFileTranslator : public MPxFileTranslator
{
public:

    AlembicImportFileTranslator() : MPxFileTranslator() {}

    ~AlembicImportFileTranslator() override {}

    MStatus reader (const MFileObject& file,
                    const MString& optionsString,
                    MPxFileTranslator::FileAccessMode mode) override;

    MFileKind identifyFile(const MFileObject& filename,
                           const char* buffer,
                           short size) const override;

    bool haveReadMethod() const override
    {
        return true;
    }

    bool haveNamespaceSupport() const override
    {
        return true;
    }

    MString defaultExtension() const override
    {
        return "abc";
    }

    MString filter() const override
    {
        return "*.abc";
    }

    static void* creator()
    {
        return new AlembicImportFileTranslator;
    }
};

#endif  // ABCIMPORT_ALEMBIC_IMPORT_FILE_TRANSLATOR_H_
